# This configuration file is Python code.  You should not
# need to change it; but if you do, you need to know that
# in Python, the *indentation matters*.

# The following will normally be empty lists, like this:
#
#ignore_ADCPs = []
#ignore_other_sensors = []
#
# But if you want to run with only a subset of the ADCPs
# and/or ancillary sensors that are defined in this file,
# you can list the ones you want to ignore like this:
#
#ignore_ADCPs = ['wh300', 'os75']
#ignore_other_sensors = ['GPS']
#
# In this case, you are listing the 'instrument' field of each
# ADCP or sensor you wish to exclude.
#
#


# ADCP (WH1200, WH300, and OS75) Baud rates are all default from RDI 9600.
# All Nav Data is 4800 baud.
# 1 GPS input from a Trimble DMS232 sending GGA, RMC, and VTG sentences.
# Heading from our Sperry Marine, NAVIGAT X MK 1 Digital Gyro Compass
# TSS motion reference unit (MRU), model is a DMS-05, sending a PRDID sentence
#            with roll and pitch (no heading)
#  FURUNO SC-50  GGA, RMC, VTG, and HDT.


#ignore_ADCPs = []
#ignore_ADCPs = ['wh300','wh600']
ignore_ADCPs = ['wh300',]
ignore_other_sensors = []
use_publishers = False


# 2-letter abbreviation for logging file prefix and constructing dbase name;
# read by procsetup.py
shipabbrev = "bh"


ADCPs = [

       { 'instrument'  :  'wh600',
          'setup'       :  'rdi_setup',
          'terminal'    :  'oswh_term',
          'defaultcmd'  :  'wh600_default.cmd',
          'commands'    :  ('ES00'),  # fixed 0 salinity
          'datatypes'   :  ('wh600',),
          'wakeup_baud' :  115200,
        },

       { 'instrument'  :  'wh300',
          'setup'       :  'rdi_setup',
          'terminal'    :  'oswh_term',
          'defaultcmd'  :  'wh300_default.cmd',
          'commands'    :  ('ES00'),  # fixed 0 salinity
          'datatypes'   :  ('wh300',),
          'wakeup_baud' :  9600
        },


        { 'instrument'  :  'bb150',
          'setup'       :  'rdi_setup',      ## RENAME ?? rdi_setup.py
          'terminal'    :  'oswh_term',
          'defaultcmd'  :  'bb150_default.cmd',
          'commands'    :  ('EA04500','ES00'),  # fixed 0 salinity
          'datatypes'   :  ('bb150',),
          'wakeup_baud' :  9600
        }

        ]


# Do not edit the next three lines:
common_opts = '-f %s -F -m 1 -H 2 ' % (shipabbrev,)
nb_opts =   '-lE -c -I'          # raw data, write a log file, log errors
oswh_opts = '-lE -c -O -I'       # -O for OS/WH data format
                                  # -c for checksum, -I to initiate pinging

sensors = [

        { 'instrument'  :  'wh600',
          'device'      :  'ttyUSB7',
          'baud'        :   38400,
          'format'      :  'binary',
          'subdir'      :  'wh600',
          'ext'         :  'raw',
          'opt'         :  oswh_opts ,
          },

         { 'instrument'  :  'wh300',
          'device'      :  'ttyUSB6',
          'baud'        :   38400,
          'format'      :  'binary',
          'subdir'      :  'wh300',
          'ext'         :  'raw',
          'opt'         :  oswh_opts ,
          },

        { 'instrument'  :  'bb150',
          'device'      :  'ttyS0',
          'baud'        :   19200,
          'format'      :  'binary',
          'subdir'      :  'bb150',
          'ext'         :  'raw',
          'opt'         :  oswh_opts,
        },


        { 'instrument'  :  ' GPS',
          'device'      :  'ttyUSB0',
          'baud'        :   4800,
          'format'      :  'ascii',
          'subdir'      :  'gpsnav',
          'ext'         :  'gps',
          'strings'     :  ('$GPGGA',),    #primary position for processing
          'messages'    :  ('ggn',),
          'opt'         :  '-Y2',
         },

        { 'instrument'  :  'POS/MV',
         'device'      :  'ttyUSB1',
         'baud'        :   9600,
          'format'      :  'ascii',
          'subdir'      :  'posmv',
          'ext'         :  'pmv',
          'strings'     :  ('$INGGA', '$PASHR'),   # use () for all
          'messages'    :  ('gps', 'pmv'),
          'opt'         :  '-Y2 -c',
         },

        { 'instrument'  :  'Gyro',
          'device'      :  'ttyUSB2',
          'baud'        :   4800,
          'format'      :  'ascii',
          'subdir'      :  'gyro',
          'ext'         :  'hdg',
          'strings'     :  ('$HEHDT',),
          'messages'    :  ('hdg',),
          'opt'         :  '-Y2 -c',
         },

        { 'instrument'  :  'GP90', # SC-50
          'device'      :  'ttyUSB3',
          'baud'        :   4800,
          'format'      :  'ascii',
          'subdir'      :  'gp90',   ## do not change dir name
          'ext'         :  'gps',
          'strings'     :  ('$GPGGA',),
          'messages'    :  ('gps',),
          'opt'         :  '-Y2 -c ',
         },


]


## enabling or disabling this occurs in procsetup_onship.py
speedlog_config = {
    'instrument'        : 'bb150',
    'serial_device'     : '',   # serial out, for SCS
    'baud'              : 9600,
    'eth_port'          : 'eno1',   # this is the NIC to serve web_speedlog.py
    'zmq_from_bin'      : "tcp://127.0.0.1:38010",
    'pub_addr'          : "tcp://127.0.0.1:38020", # uses this port
#    'heading_offset'    : xx.x,    # get from EA_estimator.py
    'scale'             : 1.0,     # multiplies velocity measurement
    'bins'              : (1,3),   # zero-based; input to python slice()
    'navg'              : 5,       # pings to average
}



## this section describes...
publishers = [
               {
               'subdir'      :  'gpsnav',
               'pub_addr'    :  'tcp://127.0.0.1:38000', # uses this port #NO SPACES
               'sample_opts' :  '-Y2 -c -s60',
               },
             ]

#### DO NOT CHANGE the following ################

ADCPs = [A for A in ADCPs if A['instrument'] not in ignore_ADCPs]
sensors = [S for S in sensors if S['instrument'] not in ignore_ADCPs]
sensors = [S for S in sensors if S['instrument'] not in ignore_other_sensors]

from uhdas.uhdas import make_publishers

# append zmq_from_bin port to opts in appropriate ADCP sensor block
make_publishers.modify_sensors_for_speedlog(sensors, speedlog_config)

# substitute publishers into sensors for zmq publishing
if use_publishers==True:
    make_publishers.modify_sensors_and_publishers(sensors, publishers)
